from setuptools import setup

setup(
	name='cnnutils',
    packages=['cnnutils'],
	version='0.0.16',
	description='A set of utility function which help build convolutional neural networks',
	url='https://github.com/igor97100/cnnutils',
    download_url='https://github.com/igor97100/cnnutils/archive/v_07.tar.gz',
	author='Igor Spiridonov',
	author_email='igor.spiridonov@protonmail.com',
	license='MIT',
    isntall_requires=['numpy'],
    keywords = ['cnn', 'convolutional', 'neural network', 'convolution']
)
